CaptureResult class

Result with data from a captured identity document page.

Constructors

CaptureResult.fromJson(Map<String, dynamic> data)
Returns a CaptureResult type from a JSON
factory

Properties

captureMode → CaptureMode
no setter
documentImage → Uint8List
The document image with some margin as Bitmap.
no setter
faceImageFeature → CaptureResultFeature?
no setter
hashCode → int
The hash code for this object.
no setterinherited
mrzFeature → CaptureResultFeature?
no setter
noFingerOnDocumentQualityCriterion → CaptureResultQualityCriterion?
no setter
noGlareOnDocumentQualityCriterion → CaptureResultQualityCriterion?
no setter
pageType → PageType?
no setter
qrCodeFeature → CaptureResultFeature?
no setter
qrCodeResult → QRCodeResult?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharpImageQualityCriterion → CaptureResultQualityCriterion?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of CaptureResult
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited