ConsolidatedIdentityData class

Data from multiple sources, combined so that for each field data from the most reliable source available is used.

Constructors

ConsolidatedIdentityData.fromJson(Map<String, dynamic> data)
Returns a ConsolidatedIdentityData type from a JSON
factory

Properties

chipCloneDetection → ConsolidatedValue
no setter
chipVerification → ConsolidatedValue
no setter
dateOfBirth → ConsolidatedValue
no setter
dateOfExpiry → ConsolidatedValue
no setter
documentCode → ConsolidatedValue
no setter
documentNumber → ConsolidatedValue
no setter
gender → ConsolidatedValue
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuingCountry → ConsolidatedValue
no setter
nameOfHolder → ConsolidatedValue
no setter
nationality → ConsolidatedValue
no setter
personalNumber → ConsolidatedValue
no setter
placeOfBirth → ConsolidatedValue
no setter
primaryIdentifier → ConsolidatedValue
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIdentifier → ConsolidatedValue
no setter
selfieVerificationProfile → ConsolidatedValue
no setter
selfieVerificationStatus → ConsolidatedValue
no setter
visualVerification → ConsolidatedValue
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of ConsolidatedIdentityData
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited