DocumentInfo class

Basic information about the scanned document.

Constructors

DocumentInfo(String documentCode, String issuingCountry, String? dateOfBirth, String? dateOfExpiry, String? edlVersion)
DocumentInfo.fromJson(Map<String, dynamic> data)
Returns a DocumentInfo type from a JSON
factory

Properties

dateOfBirth → String?
The document's owner's date of birth (yyMMdd)
no setter
dateOfExpiry → String?
The document's date of expiry (yyMMdd)
no setter
documentCode → String
The document code (2 letters)
no setter
edlVersion → String?
European Driver License version
no setter
hashCode → int
The hash code for this object.
no setterinherited
issuingCountry → String
The issuing country (alpha-3 country code)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of DocumentInfo
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited