EDLDocumentContent class

Interpretation of the data read from an Electronic Drivers License.

Inheritance

Constructors

EDLDocumentContent.fromJson(Map<String, dynamic> data)
Returns a EDLDocumentContent type from a JSON
factory

Properties

categories → List<CategoryInfo>
no setter
countryOfBirth → String?
The country of birth of the document holder
no setter
dataGroupNumbers → List<int>
List of datagroup numbers
no setteroverride
dateOfBirth → String?
Date of birth of the document holder. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document.
no setteroverride
dateOfExpiry → String?
Date of expiry of the document. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document
no setteroverride
dateOfIssue → String?
Date of issue of the document. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document.
no setteroverride
documentNumber → String?
The number of the scanned document document. Counterintuitively the document number isn't necessarily numeric.
no setteroverride
documentType → ReadIDDocumentType?
no setteroverride
fullDateOfBirth → DateTime?
If the document contains the full date of birth it is returned. In case of ICAO compliant documents this is not always present because DG11 is optional.
no setteroverride
fullDateOfExpiry → DateTime?
The date of issue as Date object.
no setter
fullDateOfIssue → DateTime?
The date of issue as Date object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
interpretedDateOfBirth → String?
Date of birth of the document holder in "dd.MM.yyyy" format. Note that for ICAO type documents, this date is possibly based on the date in data group 1, which contains the MRZ. Dates within the MRZ only contain year information in two digits, and do not contain century information. Therefore the century information in the interpreted date is based on the current system date. The interpreter makes sure that the date of birth is always in the past. When the input MRZ date is incomplete (unknown day or unknown day and month, encoded using "<<" as per ICAO Doc 9303) the interpreter will use "00".
no setteroverride
interpretedDateOfExpiry → String?
Date of birth of the document holder formatted for display purposes. Format dd.MM.yyyy Note that for ICAO type documents, this date is possibly based on the date in data group 1, which contains the MRZ. Dates within the MRZ only contain year information in two digits, and do not contain century information. Therefore the century information in the interpreted date is based on the current system date. The interpreter makes sure that the date of expiry is always after the interpreted date of birth.
no setteroverride
interpretedDateOfIssue → String?
Date of issue of the document. The format of this String is dd.MM.yyyy. Note that for ICAO type documents, this date is only present if the document contains a DG12 with this field. If it is not present the value is nil .
no setteroverride
interpretedIssuingCountry → String?
Issuing country of the document formatted for display purposes.
no setteroverride
issuingAuthority → String?
The authority that issued the document
no setteroverride
issuingCountry → String?
Three letter (ISO 3166-1 alpha-3) code indicating the country that issued the document.
no setteroverride
ldsVersion → String?
The version of the LDS (Logical Data Structure) used in the document
no setteroverride
nameOfHolder → String?
Name of the document holder. This is either a name retrieved from data group 11 (in case the name is long or contains non-ascii characters) or derived by concatenating the primary and secondary identifiers.
no setteroverride
nameOfHolderAlt1 → String?
Name of holder (alternate 1)
no setter
nameOfHolderAlt2 → String?
Name of holder (alternate 2)
no setter
personalNumber → String?
A number that identifies the holder. The content and format of this field is specific for an issuing country. Counterintuitively the personal number isn't necessarily numeric.
no setteroverride
placeOfBirth → String?
Birthplace of the document holder
no setter
placeOfBirthAlt → String?
Birthplace of the document holder (alternate)
no setter
primaryIdentifier → String?
The primary identifier of the document holder, usually their last or family name.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saiString → String?
Scanning Area Identifier
no setter
saiType → String?
Scanning Area Identifier
no setter
secondaryIdentifier → String?
The secondary identifier of the document holder, usually their first name(s).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of EDLDocumentContent
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited