ErrorResponseError class

Error response with reason and message.

Constructors

ErrorResponseError.fromJson(Map<String, dynamic> data)
Returns a ErrorResponseError type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Error's message
no setter
reason → String
Error's reason
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of ErrorResponseError
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited