Failure class

Failure information.

Inheritance

Constructors

Failure.fromJson(Map<String, dynamic> data)
Returns a Failure type from a JSON
factory

Properties

didUserSkip → bool
True if the user used the skip button on NFC screen or in dialog, otherwise false.
no setter
failureReason → FailureReason
no setter
hashCode → int
The hash code for this object.
no setterinherited
nfcAttempts → int
The number of NFC attempts that the user took prior to the failure. Only used on NFC screen, otherwise 0.
no setter
readIDSession → ReadIDSession?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → Screen?
no setter
timeOnScreen → int
The time in ms from entering the screen until the failure occurred in milliseconds.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of Failure
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited