Features class

Document features

Constructors

Features.fromJson(Map<String, dynamic> data)
Returns a Features type from a JSON
factory

Properties

document → Feature
no setter
faceImage → Feature
no setter
hashCode → int
The hash code for this object.
no setterinherited
mrz → Feature
no setter
qrCode → Feature
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of Features
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited