FinishResult class

The result of when finishing a session.

Constructors

FinishResult.fromJson(Map<String, dynamic> data)
Returns a FinishResult type from a JSON
factory

Properties

failure → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeeded → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of FinishResult
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited