Flow class abstract

Base class with common properties for all flows

Implementers

Constructors

Flow()

Properties

accessKey ← String
no getter
applicationLevelEncryptionPins ← List<String>?
no getter
baseUrl ← String
no getter
dateFormat ← DateFormat
no getter
dateSeparator ← DateSeparator
no getter
hashCode → int
The hash code for this object.
no setterinherited
instructionsPlayCount ← int
Replays the instruction animations a number of times -< 0 the animations are play endless, 0 the animations are disabled, > 0 the animations are played that many times. Default value is -1 (endless play)
no getter
isDebugEnabled ← bool
no getter
language ← String?
no getter
oauthToken ← String
no getter
opaqueID ← String?
no getter
preventSessionCommit ← bool
no getter
readIDSession ← ReadIDSession?
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ← ScreenOrientation
no getter
shouldAllowScreenshots ← bool
no getter
shouldAskDismissConfirmation ← bool
no getter
shouldMaskPersonalData ← bool
no getter
shouldOnlyShowInstructionsOnFirstUse ← bool
Sets showInstructions always enabled/disabled. Default value is false.
no getter
shouldUsePinning ← bool
no getter
tlsPins ← List<String>?
no getter
uiResources ← UIResources?
no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of Flow
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited