ICAODocumentContent class

Interpretation of the data read from a ICAO 9303 compliant Machine Readable Travel Document.

Inheritance

Constructors

ICAODocumentContent.fromJson(Map<String, dynamic> data)
Returns a ICAODocumentContent type from a JSON
factory

Properties

custodian → String?
Custodian of the document holder
no setter
dataGroupNumbers → List<int>
List of datagroup numbers
no setteroverride
dateOfBirth → String?
Date of birth of the document holder. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document.
no setteroverride
dateOfExpiry → String?
Date of expiry of the document. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document
no setteroverride
dateOfIssue → String?
Date of issue of the document. The format of this String is YYMMDD. This date is in the same format as the MRZ (Machine Readable Zone) on the document.
no setteroverride
documentCode → String?
Document code indicating the type of document. 'P' for a passport. 'I' for an Identity Document.
no setter
documentNumber → String?
The number of the scanned document document. Counterintuitively the document number isn't necessarily numeric.
no setteroverride
documentType → ReadIDDocumentType?
no setteroverride
fullDateOfBirth → DateTime?
If the document contains the full date of birth it is returned. In case of ICAO compliant documents this is not always present because DG11 is optional.
no setteroverride
gender → Gender?
no setter
hashCode → int
The hash code for this object.
no setterinherited
interpretedDateOfBirth → String?
Date of birth of the document holder in "dd.MM.yyyy" format. Note that for ICAO type documents, this date is possibly based on the date in data group 1, which contains the MRZ. Dates within the MRZ only contain year information in two digits, and do not contain century information. Therefore the century information in the interpreted date is based on the current system date. The interpreter makes sure that the date of birth is always in the past. When the input MRZ date is incomplete (unknown day or unknown day and month, encoded using "<<" as per ICAO Doc 9303) the interpreter will use "00".
no setteroverride
interpretedDateOfExpiry → String?
Date of birth of the document holder formatted for display purposes. Format dd.MM.yyyy Note that for ICAO type documents, this date is possibly based on the date in data group 1, which contains the MRZ. Dates within the MRZ only contain year information in two digits, and do not contain century information. Therefore the century information in the interpreted date is based on the current system date. The interpreter makes sure that the date of expiry is always after the interpreted date of birth.
no setteroverride
interpretedDateOfIssue → String?
Date of issue of the document. The format of this String is dd.MM.yyyy. Note that for ICAO type documents, this date is only present if the document contains a DG12 with this field. If it is not present the value is nil .
no setteroverride
interpretedIssuingCountry → String?
Issuing country of the document formatted for display purposes.
no setteroverride
interpretedNationality → String?
A natural-language version of the document holders nationality. Note that this is not necessarily the same as the country that issued the document.
no setter
issuingAuthority → String?
The authority that issued the document
no setteroverride
issuingCountry → String?
Three letter (ISO 3166-1 alpha-3) code indicating the country that issued the document.
no setteroverride
ldsVersion → String?
The version of the LDS (Logical Data Structure) used in the document
no setteroverride
mrzPrimaryIdentifier → String?
The primary identifier (last name) as read from ICAO DG1, with any filler characters replaced by spaces.
no setter
mrzSecondaryIdentifier → String?
The secondary identifiers (first names) as read from ICAO DG1, with any filler characters replaced by spaces.
no setter
mrzString → String?
The MRZ string as read from ICAO DG1, without whitespace.
no setter
nameOfHolder → String?
Name of the document holder. This is either a name retrieved from data group 11 (in case the name is long or contains non-ascii characters) or derived by concatenating the primary and secondary identifiers.
no setteroverride
nationality → String?
The nationality of the document holder. Note that this is not necessarily the same as the country that issued the document.
no setter
optionalData → String?
Optional data in document MRZ.
no setter
optionalData2 → String?
Optional data2 in document MRZ (Only for TD1 documents).
no setter
otherNames → List<String>?
The other names of the document holder. These may contain characters in non latin alphabets.
no setter
permanentAddress → List<String>?
The permanent address of the document holder.
no setter
personalNumber → String?
A number that identifies the holder. The content and format of this field is specific for an issuing country. Counterintuitively the personal number isn't necessarily numeric.
no setteroverride
placeOfBirth → List<String>?
The place of birth of the document holder.
no setter
primaryIdentifier → String?
The primary identifier of the document holder, usually their last or family name.
no setteroverride
profession → String?
The profession of the document holder.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIdentifier → String?
The secondary identifier of the document holder, usually their first name(s).
no setteroverride
telephone → String?
The telephone number of the document holder.
no setter
title → String?
The title of the document holder.
no setter
unicodeVersion → String?
The unicode version used to encode text in the document.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of ICAODocumentContent
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited