NFCAccessKey class abstract

NFC access key used for reading the NFC chip

Implementers

Constructors

NFCAccessKey()
NFCAccessKey.fromJson(Map<String, dynamic> data)
Returns a NFCAccessKey type from a JSON
factory

Properties

documentType → DocumentType
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of NFCAccessKey
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited