NFCFlow class abstract

Base class for NFC only flows

Inheritance
Implementers

Constructors

NFCFlow()

Properties

accessKey ← String
no getteroverride
allowedDataGroupsToRead ← List<DataGroup>?
no getter
allowSkipReadingAfterAttempts ← int
no getter
applicationLevelEncryptionPins ← List<String>?
no getteroverride
baseUrl ← String
no getteroverride
dateFormat ← DateFormat
no getteroverride
dateSeparator ← DateSeparator
no getteroverride
hashCode → int
The hash code for this object.
no setterinherited
instructionsPlayCount ← int
Replays the instruction animations a number of times -< 0 the animations are play endless, 0 the animations are disabled, > 0 the animations are played that many times. Default value is -1 (endless play)
no getteroverride
isDebugEnabled ← bool
no getteroverride
language ← String?
no getteroverride
oauthToken ← String
no getteroverride
opaqueID ← String?
no getteroverride
preventSessionCommit ← bool
no getteroverride
readIDSession ← ReadIDSession?
no getteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ← ScreenOrientation
no getteroverride
shouldAllowScreenshots ← bool
no getteroverride
shouldAskDismissConfirmation ← bool
no getteroverride
shouldMaskPersonalData ← bool
no getteroverride
shouldOnlyShowInstructionsOnFirstUse ← bool
Sets showInstructions always enabled/disabled. Default value is false.
no getteroverride
shouldReadImages ← bool
no getter
shouldShowInstructionCarousel ← bool
Whether the instruction carousel should be shown. Default value is true.
no getter
shouldShowNFCResult ← bool
no getter
shouldUsePinning ← bool
no getteroverride
tlsPins ← List<String>?
no getteroverride
uiResources ← UIResources?
no getteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of NFCFlow
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited