NFCOnlyFlow class

This flow only performs the NFC reading steps.

Inheritance
Implemented types
Available extensions

Constructors

NFCOnlyFlow(NFCAccessKey nfcAccessKey, DocumentInfo? documentInfo)

Properties

accessKey ← String
no getterinherited
allowedDataGroupsToRead ← List<DataGroup>?
no getterinherited
allowSkipReadingAfterAttempts ← int
no getterinherited
applicationLevelEncryptionPins ← List<String>?
no getterinherited
baseUrl ← String
no getterinherited
dateFormat ← DateFormat
no getterinherited
dateSeparator ← DateSeparator
no getterinherited
hashCode → int
The hash code for this object.
no setterinherited
instructionsPlayCount ← int
Replays the instruction animations a number of times -< 0 the animations are play endless, 0 the animations are disabled, > 0 the animations are played that many times. Default value is -1 (endless play)
no getterinherited
isDebugEnabled ← bool
no getterinherited
language ← String?
no getterinherited
oauthToken ← String
no getterinherited
opaqueID ← String?
no getterinherited
preventChipSupportDialog ← bool
no getterinherited
preventSessionCommit ← bool
no getterinherited
readIDSession ← ReadIDSession?
no getterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ← ScreenOrientation
no getterinherited
shouldAllowScreenshots ← bool
no getterinherited
shouldAskDismissConfirmation ← bool
no getterinherited
shouldMaskPersonalData ← bool
no getterinherited
shouldOnlyShowInstructionsOnFirstUse ← bool
Sets showInstructions always enabled/disabled. Default value is false.
no getterinherited
shouldReadImages ← bool
no getterinherited
shouldShowInstructionCarousel ← bool
Whether the instruction carousel should be shown. Default value is true.
no getterinherited
shouldShowNFCResult ← bool
no getterinherited
shouldUsePinning ← bool
no getterinherited
tlsPins ← List<String>?
no getterinherited
uiResources ← UIResources?
no getterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obfuscationSafeStringify() → String

Available on ReadIDFlow, provided by the Stringify extension

toJson() → Map<String, dynamic>
Returns a JSON-representation of NFCOnlyFlow
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited