NFCResult class

The NFC result object with the collected chip information.

Inheritance

Constructors

NFCResult.fromJson(Map<String, dynamic> data)
Returns a NFCResult type from a JSON
factory

Properties

faceImage → Uint8List?
Gets the face image from the chip. Returns the face image as Bitmap or null if not read of not exists
no setter
hashCode → int
The hash code for this object.
no setterinherited
readIDSession → ReadIDSession?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureImage → Uint8List?
Gets the signature image from the chip. Return the signature image as Bitmap or null if not read or not exists
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of NFCResult
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited