NFCWithVIZFallbackFlow class

This flow goes to fallback flow if the document's NFC chip cannot be read.

Inheritance
Implemented types
Available extensions

Constructors

NFCWithVIZFallbackFlow()

Properties

accessKey ← String
no getteroverride
allowedDocumentTypes ← List<DocumentType>
no getteroverride
applicationLevelEncryptionPins ← List<String>?
no getteroverride
baseUrl ← String
no getteroverride
dateFormat ← DateFormat
no getteroverride
dateSeparator ← DateSeparator
no getteroverride
hashCode → int
The hash code for this object.
no setterinherited
instructionsPlayCount ← int
Replays the instruction animations a number of times -< 0 the animations are play endless, 0 the animations are disabled, > 0 the animations are played that many times. Default value is -1 (endless play)
no getteroverride
isDebugEnabled ← bool
no getteroverride
language ← String?
no getteroverride
oauthToken ← String
no getteroverride
opaqueID ← String?
no getteroverride
preventSessionCommit ← bool
no getteroverride
readIDSession ← ReadIDSession?
no getteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ← ScreenOrientation
no getteroverride
shouldAllowScreenshots ← bool
no getteroverride
shouldAskDismissConfirmation ← bool
no getteroverride
shouldMaskPersonalData ← bool
no getteroverride
shouldOnlyShowInstructionsOnFirstUse ← bool
Sets showInstructions always enabled/disabled. Default value is false.
no getteroverride
shouldShowDocumentSelection ← bool
no getteroverride
shouldShowInstructionCarousel ← bool
Whether the instruction carousel should be shown. Default value is true.
no getteroverride
shouldShowNFCResult ← bool
no getteroverride
shouldShowVIZConfirmation ← bool
no getteroverride
shouldShowVIZResult ← bool
no getteroverride
shouldUsePinning ← bool
no getteroverride
tlsPins ← List<String>?
no getteroverride
uiResources ← UIResources?
no getteroverride
vizFallbackMode ← VIZFallbackMode
no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obfuscationSafeStringify() → String

Available on ReadIDFlow, provided by the Stringify extension

toJson() → Map<String, dynamic>
Returns a JSON-representation of NFCWithVIZFallbackFlow
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited