OnfidoCheck class

In the Onfido API a check is a request to carry out one or more reports on an applicant.

Constructors

OnfidoCheck.fromJson(Map<String, dynamic> data)
Returns a OnfidoCheck type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → OnfidoResult?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OnfidoCheckStatus?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of OnfidoCheck
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited