OnfidoReport class

In the Onfido API a report is a single verification request, such as a Document Report or Facial Similarity Photo report.

Constructors

OnfidoReport.fromJson(Map<String, dynamic> data)
Returns a OnfidoReport type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → OnfidoResult?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OnfidoReportStatus?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of OnfidoReport
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited