QRCodeResult class

The result of decoding a QR code

Constructors

QRCodeResult.fromJson(Map<String, dynamic> data)
Returns a QRCodeResult type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validation → QRCodeValidation
no setter
value → String
The value of the QR code.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of QRCodeResult
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited