QualityCriterion class

A quality criterion

Constructors

QualityCriterion.fromJson(Map<String, dynamic> data)
Returns a QualityCriterion type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
If true, the capture component was configured to require this criterion passes before accepting the result
no setter
result → QualityCriterionResult
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of QualityCriterion
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited