ReadIDResult class

Wraps the NFCResult and VIZResult outcome from ReadID flow

Constructors

ReadIDResult({VIZResult? vizResult, NFCResult? nfcResult})
ReadIDResult.fromJson(Map<String, dynamic> data)
Returns a ReadIDResult type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nfcResult → NFCResult?
Contains the result of the NFC reading
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vizResult → VIZResult?
Contains the result of the VIZ scan
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited