ReadIDSession class

Encapsulated session where information from a single document is captured. It can contain data read through NFC as well as optically captured data.

Available extensions

Constructors

ReadIDSession.fromJson(Map<String, dynamic> data)
Returns a ReadIDSession type from a JSON
factory

Properties

commitStatus → CommitStatus?
The status of a session, that reflects whether or not ReadIDSession was committed to ReadID server.
no setter
consolidatedIdentityData → ConsolidatedIdentityData?
no setter
documentContent → DocumentContent?
no setter
hashCode → int
The hash code for this object.
no setterinherited
opaqueId → String?
The opaque identifier. This customer-provided identifier can be used by our customer to cross-reference this ReadID Session to an app session identifier.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
A unique identifier for the session
no setter
vizImages → VIZImages?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → Future<bool>

Available on ReadIDSession, provided by the StrongReferencedReadIDSession extension

toJson() → Map<String, dynamic>
Returns a JSON-representation of ReadIDSession
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited