RetrieveIProovVerifyTokenResponse class

Token response received for iProov orchestration.

Constructors

RetrieveIProovVerifyTokenResponse.fromJson(Map<String, dynamic> data)
Returns a RetrieveIProovVerifyTokenResponse type from a JSON
factory

Properties

attemptsLeft → int
The amount of attempts left for this user.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pod → String?
The pod used for the enrolment of the user. Pod stands for point of delivery and is used by iProov to indicate which environment is used
no setter
riskProfile → String?
The currently configured risk profile.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verifyToken → String
The verified iProov token
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of RetrieveIProovVerifyTokenResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited