UIEdgeInsets class

The inset distances for views

Constructors

UIEdgeInsets()
UIEdgeInsets.fromJson(Map<String, dynamic> data)
Returns a UIEdgeInsets type from a JSON
factory

Properties

bottom ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ double
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of UIEdgeInsets
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited