UIResources class

UI resources is an API to be able to change colors, images, and fonts, as described in the developer guide, which have impact on UI, on runtime.

Constructors

UIResources()
UIResources.fromJson(Map<String, dynamic> data)
Returns a UIResources type from a JSON
factory

Properties

buttonContentInsets ↔ UIEdgeInsets?
getter/setter pair
buttonCornerRadius ↔ double?
Corner radius of the buttons. Defaults to 15.
getter/setter pair
buttonFont ↔ UIFont?
getter/setter pair
buttonHeight ↔ double?
Height for the buttons. Set isDynamicTypeEnabled to false to be able to configure the height of the buttons. The height should be between 48 and 100 points. Defaults to 48.
getter/setter pair
buttonIconSize ↔ double?
Icon size when used in buttons. Defaults to 48.
getter/setter pair
buttonStrokeWidth ↔ double?
Border width of the buttons. Defaults to 1.
getter/setter pair
buttonTextSize ↔ double?
Text size of the buttons when Dynamic Type is disabled. Setting only used if isDynamicTypeEnabled = false
getter/setter pair
buttonTextWeight ↔ double?
Font weight for buttons, as CGFloat raw value. Defaults to UIFont.Weight.medium
getter/setter pair
customBundleIdentifier ↔ String?
Used to override colors, images and strings in the ReadID UI framework
getter/setter pair
customStringTableName ↔ String?
The string table to search. The string table must be part of the customBundle. If customStringTableName is nil or an empty string, ReadID UI uses Localizable.strings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDynamicTypeEnabled ↔ bool?
Enable/disable Dynamic Type. When enabled fonts in ReadID will scale with the accessibility settings. Defaults to true
getter/setter pair
rowLabelFont ↔ UIFont?
getter/setter pair
rowLabelTextSize ↔ double?
Text size for the Cell top description label when Dynamic Type is disabled
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionHeaderFont ↔ UIFont?
getter/setter pair
sectionHeaderTextSize ↔ double?
Text size for section headers when Dynamic Type is disabled. Setting only used if isDynamicTypeEnabled = false
getter/setter pair
textFieldFont ↔ UIFont?
getter/setter pair
textFont ↔ UIFont?
getter/setter pair
textSize ↔ double?
Text size when Dynamic Type is disabled. Setting only used if isDynamicTypeEnabled = false. Defaults to 17
getter/setter pair
titleFont ↔ UIFont?
getter/setter pair
wireframeStrokeWidth ↔ double?
Border width of VIZ wireframe. Defaults to 4.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of UIResources
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited