VIZQRCodeSession class

This object represents QR Code data provided by the VIZ Capture component.

Constructors

VIZQRCodeSession.fromJson(Map<String, dynamic> data)
Returns a VIZQRCodeSession type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
qrCodeType ↔ QRCodeType
getter/setter pair
qrResult ↔ String
The QR Code result
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of VIZQRCodeSession
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited