VIZResult class

The MRZ result object with the collected MRZ information.

Inheritance

Constructors

VIZResult.fromJson(Map<String, dynamic> data)
Returns a VIZResult type from a JSON
factory

Properties

backCaptureResult → CaptureResult?
no setter
deviceNFCLocation → DeviceNFCLocation
no setter
documentInfo → DocumentInfo?
no setter
frontCaptureResult → CaptureResult?
no setter
hashCode → int
The hash code for this object.
no setterinherited
nfcAccessKey → NFCAccessKey?
no setter
nfcChipSupport → NFCChipSupport?
no setter
readIDSession → ReadIDSession?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of VIZResult
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited