ValidateIProovVerifyTokenResponse class

Response received after validating iProov token during iProov orchestration

Constructors

ValidateIProovVerifyTokenResponse.fromJson(Map<String, dynamic> data)
Returns a ValidateIProovVerifyTokenResponse type from a JSON
factory

Properties

attemptsLeft → int?
The amount of attempts left for this user.
no setter
checked → bool
If the result was checked. Returns true if checked, false otherwise
no setter
frameAvailable → bool
If there is a facial frame available. Returns true if available, false otherwise
no setter
hashCode → int
The hash code for this object.
no setterinherited
passed → bool
If the user passed. Returns true if passed, false otherwise
no setter
reason → String?
The reason of failure.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userFeedbackCodes → List<String>?
Feedback codes that can be used to guide the user before a retry. Return the feedback codes that are available, or null if not available
no setter
verifyToken → String
The verified iProov token
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of ValidateIProovVerifyTokenResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited