userFeedbackCodes property

List<String>? get userFeedbackCodes

Feedback codes that can be used to guide the user before a retry. Return the feedback codes that are available, or null if not available

Implementation

List<String>? get userFeedbackCodes =>
    _map["userFeedbackCodes"] as List<String>?;