VeriffResponse class

Represents a subset of the result from the veriff decision.

Constructors

VeriffResponse.fromJson(Map<String, dynamic> data)
Returns a VeriffResponse type from a JSON
factory

Properties

code → int?
Veriff's response code
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Veriff's response message
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Status of the response as given by Veriff. "success" | "fail". This is the status of the last API call of the flow that has already ended
no setter
verification → VeriffVerification?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of VeriffResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited