VeriffVerification class

Model containing the information about the verification done by veriff.

Constructors

VeriffVerification.fromJson(Map<String, dynamic> data)
Returns a VeriffVerification type from a JSON
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String?
Reason of failed verification
no setter
reasonCode → int?
Reason code of the verification
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the verification. Will be either "approved", "resubmission_requested", or “declined". The values “review", “expired", and "abandoned" are also verification status values defined in Veriff docs, but are not supported.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of VeriffVerification
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited