VerifyOnfidoResponse class

The verify Onfido response with the state, the Onfido response or the error response.

Constructors

VerifyOnfidoResponse.fromJson(Map<String, dynamic> data)
Returns a VerifyOnfidoResponse type from a JSON
factory

Properties

errorResponse → ErrorResponse?
no setter
hashCode → int
The hash code for this object.
no setterinherited
onfidoResponse → OnfidoResponse?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ReadIDState
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a JSON-representation of VerifyOnfidoResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited